##  Step 3: Review User Details
After defining the user and setting permissions, review the user details on the Review and create page, then choose Create user.
![AWS IAM Review and create user page showing user details, permissions, and tag options.](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loiof22e38adee634c16afcfd87c5fced69a_LowRes.png)
Reviewing User Details
